permafrost: Permafrost data

permafrostR Documentation

Permafrost data

Description

A small data set of permafrost type with correlated terrain attributes

Usage

permafrost

Format

permafrost

A data frame with 400 rows and 8 columns

Permafrost type classification from central Yukon, with corresponding values derived from the Canadian Digital Elevation Model.


SAiVE documentation built on May 29, 2024, 6:48 a.m.