| veg | R Documentation |
Raster of vegetation types
veg
vegA tif file loaded as a terra spatRaster
A small subset of the North American Land Cover dataset produced by the Commission for Environmental Cooperation, resampled to match cell size of other rasters in this package.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.