| wbtCheck | R Documentation |
Checks for the existence of WhiteboxTools in its default directory and installs it if necessary or if force = TRUE.
wbtCheck(force = FALSE, silent)
force |
Set TRUE to force update of WhiteboxTools binaries. |
silent |
TRUE to suppress console messages other than those explaining that Whitebox Tools binaries are being installed. |
Returns the version number of the installed binaries and (if necessary) installs WhiteboxTools in its default location.
Ghislain de Laplante (gdela069@uottawa.ca or ghislain.delaplante@yukon.ca)
#Check if WhiteboxTools binaries are installed. If not, install latest version.
wbtCheck()
# Update WhiteboxTools binaries if they are already installed.
wbtCheck(force = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.