| permafrost | R Documentation |
A small data set of permafrost type with correlated terrain attributes
permafrost
permafrostA data frame with 400 rows and 8 columns
Permafrost type classification from central Yukon, with corresponding values derived from the Canadian Digital Elevation Model.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.